@@ -1,21 +1,7 @@
 /*
  *  Copyright 2018-2019  Andreas Cord-Landwehr <cordlandwehr@kde.org>
  *
- *  This program is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU General Public License as
- *  published by the Free Software Foundation; either version 2 of
- *  the License or (at your option) version 3 or any later version
- *  accepted by the membership of KDE e.V. (or its successor approved
- *  by the membership of KDE e.V.), which shall act as a proxy
- *  defined in Section 14 of version 3 of the license.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #include "trainingaction.h"
@@ -50,7 +36,7 @@ TrainingAction::TrainingAction(std::shared_ptr<IPhrase> phrase, ISessionActions
     if (m_phrase) {
         m_text = phrase->text();
     }
-    connect(phrase.get(), &IPhrase::textChanged, this, [=](){
+    connect(phrase.get(), &IPhrase::textChanged, this, [=]() {
         m_text = phrase->text();
         emit textChanged(m_text);
     });
@@ -86,9 +72,12 @@ QVariant TrainingAction::data(const QModelIndex &index, int role) const
     }
 
     switch (role) {
-    case ModelDataRole: return QVariant::fromValue<QObject*>(m_actions.at(index.row()));
-    case Qt::DisplayRole: return m_text;
-    default: return QVariant();
+        case ModelDataRole:
+            return QVariant::fromValue<QObject *>(m_actions.at(index.row()));
+        case Qt::DisplayRole:
+            return m_text;
+        default:
+            return QVariant();
     }
 }
 
@@ -141,12 +130,12 @@ void TrainingAction::setChecked(bool checked)
     emit checkedChanged(m_checked);
 }
 
-QObject * TrainingAction::icon()
+QObject *TrainingAction::icon()
 {
-    return qobject_cast<QObject*>(&m_icon);
+    return qobject_cast<QObject *>(&m_icon);
 }
 
-IPhrase * TrainingAction::phrase() const
+IPhrase *TrainingAction::phrase() const
 {
     return m_phrase.get();
 }
@@ -156,7 +145,7 @@ QVector<TrainingAction *> TrainingAction::actions() const
     return m_actions;
 }
 
-QAbstractListModel * TrainingAction::actionModel()
+QAbstractListModel *TrainingAction::actionModel()
 {
     return this;
 }
@@ -166,7 +155,7 @@ int TrainingAction::actionsCount() const
     return m_actions.count();
 }
 
-TrainingAction * TrainingAction::action(int index) const
+TrainingAction *TrainingAction::action(int index) const
 {
     if (index < 0 || index >= m_actions.count()) {
         qWarning() << "index not in range, aborting";
