@@ -1,21 +1,7 @@
 /*
  *  Copyright 2013-2017  Andreas Cord-Landwehr <cordlandwehr@kde.org>
  *
- *  This program is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU General Public License as
- *  published by the Free Software Foundation; either version 2 of
- *  the License or (at your option) version 3 or any later version
- *  accepted by the membership of KDE e.V. (or its successor approved
- *  by the membership of KDE e.V.), which shall act as a proxy
- *  defined in Section 14 of version 3 of the license.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
 #include "application.h"
@@ -26,6 +12,8 @@
 #include <KAboutData>
 #include <KCrash>
 #include <KLocalizedString>
+#include <QIcon>
+#include <QCommandLineParser>
 
 int main(int argc, char **argv)
 {
@@ -41,7 +29,7 @@ int main(int argc, char **argv)
                          ARTIKULATE_VERSION_STRING,
                          i18nc("@title KAboutData: short program description", "Artikulate Pronunciation Trainer"),
                          KAboutLicense::GPL_V2,
-                         i18nc("@info:credit", "(c) 2013-2019 The Artikulate Developers"),
+                         i18nc("@info:credit", "(c) 2013-2020 The Artikulate Developers"),
                          i18nc("@title Short program description", "Train your pronunciation in a foreign language."));
     aboutData.setProgramLogo(app.windowIcon());
 
@@ -56,6 +44,10 @@ int main(int argc, char **argv)
     aboutData.setTranslator(i18nc("NAME OF TRANSLATORS", "Your names"), i18nc("EMAIL OF TRANSLATORS", "Your emails"));
 
     KAboutData::setApplicationData(aboutData);
+    QCommandLineParser parser;
+    aboutData.setupCommandLine(&parser);
+    parser.process(app);
+    aboutData.processCommandLine(&parser);
     KCrash::initialize();
     new MainWindow();
 
